# lectio.py

![](https://img.shields.io/github/license/dnorhoj/lectio.py)


*Please note: This library is nowhere close to done.*

The best way to get data from Lectio with Python 3.

The goal of this library,
is to be able to fetch different parts of the Lectio interface in a readable format.

You can read the documentation

## How do i use this?

To use this repository feel free to check the documentation [here](https://lectiopy.rtfd.io/).

## Todo

* [ ] Finish authentication check
* [ ] Make a better README
* [ ] Start doing the hard part (basically everything)

## Contributing

If you want to contribute, you can just fork this repository and start a pull request.

If you notice something that isn't working as intended you can start an issue.

## License

This repository uses the `GNU Lesser General Public License v3.0` you can read more about it in [LICENSE](LICENSE).